@@ -130,16 +130,24 @@ _crack_uid = None
 
 
 class Danmaku(object):
+    FONT_SIZE_EXTREME_SMALL = 12
+    FONT_SIZE_SUPER_SMALL = 16
     FONT_SIZE_SMALL = 18
-    FONT_SIZE_BIG = 36
     FONT_SIZE_NORMAL = 25
+    FONT_SIZE_BIG = 36
+    FONT_SIZE_SUPER_BIG = 45
+    FONT_SIZE_EXTREME_BIG = 64
     MODE_FLY = 1
     MODE_TOP = 5
     MODE_BOTTOM = 4
+    MODE_REVERSE = 6
+    TYPE_NORMAL = 0
+    TYPE_SUBTITLE = 1
 
     def __init__(self, text: str, dm_time: float = 0.0, send_time: float = time.time(), crc32_id: str = None
-                 , color: Color = None,
-                 mode: int = MODE_FLY, font_size: int = FONT_SIZE_NORMAL, is_sub: bool = False):
+                 , color: Color = None, weight: int = -1, id_: int = -1, id_str: str = "", action: str = '',
+                 mode: int = MODE_FLY, font_size: int = FONT_SIZE_NORMAL, is_sub: bool = False, pool: int = -1,
+                 attr: int = -1):
         self.dm_time = datetime.timedelta(seconds=dm_time)
         self.send_time = datetime.datetime.fromtimestamp(send_time)
         self.crc32_id = crc32_id
@@ -152,6 +160,13 @@ class Danmaku(object):
         self.is_sub = is_sub
         self.text = text
 
+        self.weight = weight
+        self.id = id_
+        self.id_str = id_str
+        self.action = action
+        self.pool = pool
+        self.attr = attr
+
     def __str__(self):
         ret = "%s, %s, %s" % (self.send_time, self.dm_time, self.text)
         return ret
@@ -337,7 +352,7 @@ class CrackUid(object):
 # 请求相关
 
 
-def request(method: str, url: str, params=None, data=None, cookies=None, headers=None, **kwargs):
+def request(method: str, url: str, params=None, data=None, cookies=None, headers=None, data_type: str = "form", **kwargs):
     if params is None:
         params = {}
     if data is None:
@@ -346,6 +361,8 @@ def request(method: str, url: str, params=None, data=None, cookies=None, headers
         cookies = {}
     if headers is None:
         headers = copy.deepcopy(DEFAULT_HEADERS)
+    if data_type.lower() == "json":
+        headers['Content-Type'] = "application/json"
     st = {
         "url": url,
         "params": params,
@@ -387,9 +404,10 @@ def request(method: str, url: str, params=None, data=None, cookies=None, headers
         raise exceptions.NetworkException(req.status_code)
 
 
-def get(url, params=None, cookies=None, headers=None, **kwargs):
+def get(url, params=None, cookies=None, headers=None, data_type: str = "form", **kwargs):
     """
     专用GET请求
+    :param data_type:
     :param url:
     :param params:
     :param cookies:
@@ -397,13 +415,14 @@ def get(url, params=None, cookies=None, headers=None, **kwargs):
     :param kwargs:
     :return:
     """
-    resp = request("GET", url=url, params=params, cookies=cookies, headers=headers, **kwargs)
+    resp = request("GET", url=url, params=params, cookies=cookies, headers=headers, data_type=data_type, **kwargs)
     return resp
 
 
-def post(url, cookies, data=None, headers=None, **kwargs):
+def post(url, cookies, data=None, headers=None, data_type: str = "form", **kwargs):
     """
     专用POST请求
+    :param data_type:
     :param url:
     :param cookies:
     :param data:
@@ -411,13 +430,14 @@ def post(url, cookies, data=None, headers=None, **kwargs):
     :param kwargs:
     :return:
     """
-    resp = request("POST", url=url, data=data, cookies=cookies, headers=headers, **kwargs)
+    resp = request("POST", url=url, data=data, cookies=cookies, headers=headers, data_type=data_type, **kwargs)
     return resp
 
 
-def delete(url, params=None, data=None, cookies=None, headers=None, **kwargs):
+def delete(url, params=None, data=None, cookies=None, headers=None, data_type: str = "form", **kwargs):
     """
     专用DELETE请求
+    :param data_type:
     :param url:
     :param params:
     :param data:
@@ -426,7 +446,7 @@ def delete(url, params=None, data=None, cookies=None, headers=None, **kwargs):
     :param kwargs:
     :return:
     """
-    resp = request("DELETE", url=url, params=params, data=data, cookies=cookies, headers=headers, **kwargs)
+    resp = request("DELETE", url=url, params=params, data=data, cookies=cookies, headers=headers, data_type=data_type, **kwargs)
     return resp
 
 
@@ -500,6 +520,27 @@ def upload_image(image_path: str, verify: Verify):
     resp = post(url=api["url"], data=data, cookies=verify.get_cookies(), files=files)
     return resp
 
+
+def read_varint(stream: bytes):
+    """
+    读取varint
+    :param stream:
+    :return: value（真实值）, length（varint长度）
+    """
+    value = 0
+    position = 0
+    shift = 0
+    while True:
+        if position >= len(stream):
+            break
+        byte = stream[position]
+        value += (byte & 0b01111111) << shift
+        if byte & 0b10000000 == 0:
+            break
+        position += 1
+        shift += 7
+    return value, position + 1
+
 """
 みゃーねか？どうしたみゃーね～
 ーー「私に天使が舞い降りた！」
